==> react-native-ui-xep-0.1.20.tgz: package/src/atoms/TreeDropdown/TreeDropdownContext.tsx <==
import React, { FC, useState, ReactNode } from 'react';
import { RemoveItemProps } from './TreeDropdown';

export type TreeDropdownContextProps = {
  selectedList: any[];
  setSelectedList: (val: any[]) => void;
  selectChild: (childId: string, parentId: string) => void;
  removeTag: (val: RemoveItemProps) => void;
};
type selectedParentProp = {
  [key: string]: string;
};
const TreeDropdownContext = React.createContext<{
  current?: TreeDropdownContextProps;
}>({});

type ProviderProps = {
  parentName: string;
  childName: string;
  children: ReactNode;
};
export const TreeDropdownContextProvider: FC<ProviderProps> = (
  props: ProviderProps
) => {
  const { children, childName, parentName } = props;
  const [selectedList, setSelectedList] = useState<any>([]);
  const selectChild = (childId: string, parentId: string) => {
    const temp: any = selectedList.slice();
    if (temp.length === 0) {
      temp.push({
        [parentName]: parentId,
        [childName]: [childId],
      });
    } else {
      const i = temp.findIndex(
        (val: selectedParentProp) => val[parentName] === parentId
      );
      if (i > -1) {
        const v = temp[i];
        const childI = v[childName].findIndex((val: string) => val === childId);
        if (childI > -1) {
          if (v[childName].length === 1) {
            temp.splice(i, 1);
          } else {
            v[childName].splice(childI, 1);
            temp[i] = v;
          }
        } else {
          v[childName].push(childId);
          temp[i] = v;
        }
      } else {
        temp.push({
          [parentName]: parentId,
          [childName]: [childId],
        });
      }
    }
    setSelectedList(temp);
    // console.log('furious ', temp);
  };
  const removeTag = (item: RemoveItemProps) => {
    const temp = selectedList.slice();
    const x = temp.findIndex(
      (val: { [x: string]: string | undefined }) =>
        val[parentName] === item.parentId
    );
    if (x === -1) {
      return;
    }
    const ind = temp[x][childName].findIndex(
      (itm: string) => itm === item.childId
    );
    if (ind > -1) {
      if (temp[x][childName].length === 1) {
        temp.splice(x, 1);
      } else {
        temp[x][childName].splice(ind, 1);
      }
    }
    setSelectedList(temp);
  };

  return (
    <TreeDropdownContext.Provider
      value={{
        current: {
          setSelectedList,
          selectedList,
          selectChild,
          removeTag,
        },
      }}
    >
      {children}
    </TreeDropdownContext.Provider>
  );
};

export default TreeDropdownContext;

==> react-native-ui-xep-0.1.49.tgz: package/src/atoms/TreeDropdown/TreeDropdownContext.tsx <==
import React, { FC, useState, ReactNode } from 'react';
import { RemoveItemProps } from './TreeDropdown';

export type TreeDropdownContextProps = {
  selectedList: any[];
  setSelectedList: (val: any[]) => void;
  selectChild: (childId: string, parentId: string) => void;
  removeTag: (val: RemoveItemProps) => any;
};
type selectedParentProp = {
  [key: string]: string;
};
const TreeDropdownContext = React.createContext<{
  current?: TreeDropdownContextProps;
}>({});

type ProviderProps = {
  parentName: string;
  childName: string;
  children: ReactNode;
};
export const TreeDropdownContextProvider: FC<ProviderProps> = (
  props: ProviderProps
) => {
  const { children, childName, parentName } = props;
  const [selectedList, setSelectedList] = useState<any>([]);
  const selectChild = (childId: string, parentId: string) => {
    const temp: any = selectedList.slice();
    if (temp.length === 0) {
      temp.push({
        [parentName]: parentId,
        [childName]: [childId],
      });
    } else {
      const i = temp.findIndex(
        (val: selectedParentProp) => val[parentName] === parentId
      );
      if (i > -1) {
        const v = temp[i];
        const childI = v[childName].findIndex((val: string) => val === childId);
        if (childI > -1) {
          if (v[childName].length === 1) {
            temp.splice(i, 1);
          } else {
            v[childName].splice(childI, 1);
            temp[i] = v;
          }
        } else {
          v[childName].push(childId);
          temp[i] = v;
        }
      } else {
        temp.push({
          [parentName]: parentId,
          [childName]: [childId],
        });
      }
    }
    setSelectedList(temp);
    // console.log('furious ', temp);
  };
  const removeTag = (item: RemoveItemProps): any => {
    const temp = selectedList.slice();
    const x = temp.findIndex(
      (val: { [x: string]: string | undefined }) =>
        val[parentName] === item.parentId
    );
    if (x === -1) {
      return;
    }
    const ind = temp[x][childName].findIndex(
      (itm: string) => itm === item.childId
    );
    if (ind > -1) {
      if (temp[x][childName].length === 1) {
        temp.splice(x, 1);
      } else {
        temp[x][childName].splice(ind, 1);
      }
    }
    setSelectedList(temp);
    return temp;
  };

  return (
    <TreeDropdownContext.Provider
      value={{
        current: {
          setSelectedList,
          selectedList,
          selectChild,
          removeTag,
        },
      }}
    >
      {children}
    </TreeDropdownContext.Provider>
  );
};

export default TreeDropdownContext;
